@@ -6,10 +6,13 @@ from typing import Optional
 class ScoringInput:
     id_: Optional[str]
     name_given: Optional[str]
+    name_middle: Optional[str]
+    name_middle_initial: Optional[str]
     name_family: Optional[str]
     gender: Optional[str]
     birth_date: Optional[str]
     address_postal_code: Optional[str]
+    address_postal_code_first_five: Optional[str]
     address_line_1: Optional[str]
     address_line_1_st_num: Optional[str]
     email: Optional[str]
@@ -23,4 +26,5 @@ class ScoringInput:
     email_username: Optional[str]
     is_adult_today: Optional[bool]
     ssn: Optional[str]
+    ssn_last4: Optional[str]
     meta_security_client_slug: Optional[str]
