@@ -1,6 +1,7 @@
 import dataclasses
 import json
 from datetime import datetime, date
+from enum import Enum
 from typing import Any
 
 
@@ -21,6 +22,8 @@ class EnhancedJSONEncoder(json.JSONEncoder):
     def default(self, o: Any) -> Any:
         if dataclasses.is_dataclass(o):
             return dataclasses.asdict(o)
+        if isinstance(o, Enum):
+            return o.value
         if isinstance(o, (datetime, date)):
             return o.isoformat()
         return super().default(o)
