@@ -3,10 +3,13 @@ from pathlib import Path
 import csv
 from typing import Dict, Optional, List
 
+# noinspection PyPackageRequirements
 import pytest
 
 # noinspection PyPackageRequirements
 from fhir.resources.address import Address
+
+# noinspection PyPackageRequirements
 from fhir.resources.bundle import Bundle, BundleEntry
 
 # noinspection PyPackageRequirements
@@ -39,10 +42,13 @@ def create_patient_resource(row: Dict[str, str]) -> Patient:
 
     if row["FIRST"]:
         first_: str = row["FIRST"]
-        patient.name[0].given.append(first_)
+        if first_:
+            # noinspection PyUnresolvedReferences,PyTypeChecker
+            patient.name[0].given.append(first_)
 
     if row["MIDDLE"]:
         middle: str = row["MIDDLE"]
+        # noinspection PyUnresolvedReferences
         patient.name[0].given.append(middle)
 
     if row["SUFFIX"]:
@@ -76,7 +82,9 @@ def create_patient_resource(row: Dict[str, str]) -> Patient:
         address_2 = row["ADDRESS2"]
         if not patient.address[0].line:
             patient.address[0].line = []
-        patient.address[0].line.append(address_2)
+        if address_2:
+            # noinspection PyTypeChecker
+            patient.address[0].line.append(address_2)
 
     if row["CITY"]:
         patient.address[0].city = row["CITY"]
@@ -102,7 +110,7 @@ def test_cms_dataset() -> None:
     print("")
     data_dir: Path = Path(__file__).parent.joinpath("./")
 
-    limit: Optional[int] = 1000
+    limit: Optional[int] = 500
     limit_to_id: Optional[str] = None  # "12871231"
     # limit_to_id: Optional[str] = "15565179"
 
@@ -181,7 +189,8 @@ def test_cms_dataset() -> None:
             if len(scores) > 0:
                 first_rule_score = scores[0].rule_scores[0]
                 print(
-                    f"{first_rule_score.rule_name} = {first_rule_score.rule_score} ({first_rule_score.rule_description})"
+                    f"{first_rule_score.rule_name} = {first_rule_score.rule_score} "
+                    + f"({first_rule_score.rule_description})"
                 )
                 for score in scores:
                     print(score.to_json())
@@ -195,9 +204,6 @@ def test_cms_dataset() -> None:
             score_of_source_record = [
                 score for score in scores if score.id_source == score.id_target
             ][0]
-            scores_of_other_records = [
-                score for score in scores if score.id_source != score.id_target
-            ]
             for score in scores:
                 if score.total_score > score_of_source_record.total_score:
                     failed_records_with_higher_probabilities.append(score)
